@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 - Noorul Islam K M
 #
@@ -24,5 +23,5 @@ class TestOperationController(base.TestCase):
     def test_operations_get_all(self):
         resp, body = self.client.get('v1/operations')
         data = json.loads(body)
-        self.assertEqual(resp.status, 200)
-        self.assertEqual(data, [])
+        self.assertEqual(200, resp.status)
+        self.assertEqual([], data)
